==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/Form.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
import { FormDataEventArgs } from "./FormDataEventArgs";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
var Form = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Form, _super);
    function Form() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = new WCNativeHelper();
        _this.h = null;
        _this.submit = null;
        _this.reset = null;
        return _this;
    }
    Object.defineProperty(Form.prototype, "d", {
        get: function () {
            return this.c;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Form.prototype, "nativeElement", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.c.n = this.h;
        },
        enumerable: false,
        configurable: true
    });
    Form.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(Form.prototype, "e", {
        get: function () {
            var ret_ = this.d.m("novalidate");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.u("novalidate", value_);
        },
        enumerable: false,
        configurable: true
    });
    Form.prototype.submitChanged = function () {
        var _this = this;
        if (this.submit != null) {
            this.d.q("submit", function (a) { return _this.submit(_this, FormDataEventArgs.b(a)); });
        }
        else {
            this.d.t("submit");
        }
    };
    Form.prototype.resetChanged = function () {
        var _this = this;
        if (this.reset != null) {
            this.d.q("reset", function (a) { return _this.reset(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.d.t("reset");
        }
    };
    Form.prototype.f = function () {
        return (this.nativeElement.submit());
    };
    Form.prototype.j = function () {
        this.nativeElement.reset();
    };
    Form.prototype.g = function () {
        return (this.nativeElement.reportValidity());
    };
    Form.$t = markType(Form, 'Form', BaseElement.$);
    return Form;
}(BaseElement));
export { Form };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/Form.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
import { FormDataEventArgs } from "./FormDataEventArgs";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
var Form = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Form, _super);
    function Form() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = new WCNativeHelper();
        _this.h = null;
        _this.submit = null;
        _this.reset = null;
        return _this;
    }
    Object.defineProperty(Form.prototype, "d", {
        get: function () {
            return this.c;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Form.prototype, "nativeElement", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.c.o = this.h;
        },
        enumerable: false,
        configurable: true
    });
    Form.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(Form.prototype, "e", {
        get: function () {
            var ret_ = this.d.n("novalidate");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("novalidate", value_);
        },
        enumerable: false,
        configurable: true
    });
    Form.prototype.submitChanged = function () {
        var _this = this;
        if (this.submit != null) {
            this.d.r("submit", function (a) { return _this.submit(_this, FormDataEventArgs.b(a)); });
        }
        else {
            this.d.u("submit");
        }
    };
    Form.prototype.resetChanged = function () {
        var _this = this;
        if (this.reset != null) {
            this.d.r("reset", function (a) { return _this.reset(_this, VoidEventArgs.b(a)); });
        }
        else {
            this.d.u("reset");
        }
    };
    Form.prototype.f = function () {
        return (this.nativeElement.submit());
    };
    Form.prototype.j = function () {
        this.nativeElement.reset();
    };
    Form.prototype.g = function () {
        return (this.nativeElement.reportValidity());
    };
    Form.$t = markType(Form, 'Form', BaseElement.$);
    return Form;
}(BaseElement));
export { Form };
